
#line 3 "<stdout>"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer setkeyyy_create_buffer
#define yy_delete_buffer setkeyyy_delete_buffer
#define yy_flex_debug setkeyyy_flex_debug
#define yy_init_buffer setkeyyy_init_buffer
#define yy_flush_buffer setkeyyy_flush_buffer
#define yy_load_buffer_state setkeyyy_load_buffer_state
#define yy_switch_to_buffer setkeyyy_switch_to_buffer
#define yyin setkeyyyin
#define yyleng setkeyyyleng
#define yylex setkeyyylex
#define yylineno setkeyyylineno
#define yyout setkeyyyout
#define yyrestart setkeyyyrestart
#define yytext setkeyyytext
#define yywrap setkeyyywrap
#define yyalloc setkeyyyalloc
#define yyrealloc setkeyyyrealloc
#define yyfree setkeyyyfree

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 37
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

#if defined(__FreeBSD__)
#ifndef __STDC_LIMIT_MACROS
#define	__STDC_LIMIT_MACROS
#endif
#include <sys/cdefs.h>
#include <stdint.h>
#else
#define	__dead2
#endif

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined(__FreeBSD__) || \
    (defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L)

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE setkeyyyrestart(setkeyyyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 1024
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern yy_size_t setkeyyyleng;

extern FILE *setkeyyyin, *setkeyyyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up setkeyyytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up setkeyyytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	yy_size_t yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via setkeyyyrestart()), so that the user can continue scanning by
	 * just pointing setkeyyyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)
#define yy_current_buffer YY_CURRENT_BUFFER

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when setkeyyytext is formed. */
static char yy_hold_char;
static yy_size_t yy_n_chars;		/* number of characters read into yy_ch_buf */
yy_size_t setkeyyyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow setkeyyywrap()'s to do buffer switches
 * instead of setting up a fresh setkeyyyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void setkeyyyrestart (FILE *input_file  );
void setkeyyy_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE setkeyyy_create_buffer (FILE *file,int size  );
void setkeyyy_delete_buffer (YY_BUFFER_STATE b  );
void setkeyyy_flush_buffer (YY_BUFFER_STATE b  );
void setkeyyypush_buffer_state (YY_BUFFER_STATE new_buffer  );
void setkeyyypop_buffer_state (void );

static void setkeyyyensure_buffer_stack (void );
static void setkeyyy_load_buffer_state (void );
static void setkeyyy_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER setkeyyy_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE setkeyyy_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE setkeyyy_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE setkeyyy_scan_bytes (yyconst char *bytes,yy_size_t len  );

void *setkeyyyalloc (yy_size_t  );
void *setkeyyyrealloc (void *,yy_size_t  );
void setkeyyyfree (void *  );

#define yy_new_buffer setkeyyy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        setkeyyyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            setkeyyy_create_buffer(setkeyyyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        setkeyyyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            setkeyyy_create_buffer(setkeyyyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *setkeyyyin = (FILE *) 0, *setkeyyyout = (FILE *) 0;

typedef int yy_state_type;

extern int setkeyyylineno;

int setkeyyylineno = 1;

extern char *setkeyyytext;
#define yytext_ptr setkeyyytext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  ) __dead2;

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up setkeyyytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	(yytext_ptr) -= (yy_more_len); \
	setkeyyyleng = (size_t) (yy_cp - (yytext_ptr)); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 90
#define YY_END_OF_BUFFER 91
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[564] =
    {   0,
        0,    0,    0,    0,    0,    0,    0,    0,   91,   89,
       77,   78,   89,   79,   88,   89,   81,   84,   84,   87,
       80,   82,   83,   87,   87,   87,   87,   87,   87,   87,
       87,   87,   87,   87,   87,   87,   87,   87,   17,   17,
       17,   17,   17,   17,   17,   17,   18,   17,   17,   17,
       17,   17,   17,   17,   17,   17,   17,   17,   17,   17,
       17,   17,   87,   87,   87,   87,   87,   84,   87,   87,
       87,   87,   87,   87,   87,   87,   77,    0,   86,   79,
       88,   19,   27,   56,   42,   16,   60,    0,    0,   65,
        0,   61,   70,   64,   87,   84,   87,   87,   20,   87,

       87,   87,   87,   87,   87,   87,   87,   87,   87,   87,
       87,   87,   87,   87,   87,   87,   87,   87,   87,   87,
       17,   17,   17,   17,   17,   17,   16,   17,   17,   17,
       17,   17,   17,   17,   17,   17,   17,   17,   17,   17,
       17,   17,   17,   17,   17,   17,   17,   17,   17,   17,
       17,   17,   17,   17,   17,   17,   17,   17,   17,   17,
       17,   87,   87,   87,   87,   87,   87,   87,   87,   87,
       87,   87,   87,   87,   87,   19,   73,   74,    0,   71,
       72,   85,    1,   87,   76,    9,   87,   87,   87,   21,
       87,   87,    4,   87,   59,   87,   57,   87,   87,   87,

       87,   87,   26,   87,   87,   87,   17,   17,   17,   17,
       17,   17,   17,    1,   17,   17,    9,   17,   17,   17,
       17,   17,   17,    4,   17,   17,   17,   17,   17,   17,
       17,   17,   17,   17,   17,   17,   17,   87,   87,   87,
       87,   26,   87,   87,   87,   87,   87,   87,   87,   87,
       87,   87,   75,   87,   87,   87,    6,   87,    7,   87,
       87,   87,    8,   87,   87,   87,   87,   87,   87,   87,
       87,   87,   87,   17,   17,   17,   17,    6,   17,    7,
       17,   17,   17,    8,   17,   17,   17,   17,   17,   17,
       17,   17,   17,   17,   87,   87,   87,   41,   87,   87,

       87,   87,   87,   87,   87,   45,   87,   87,   87,   87,
       87,   87,   87,   87,    5,   87,   87,   87,   87,   87,
       87,   87,   87,   87,   87,   87,   87,   87,   17,   17,
       17,   17,   17,    5,   17,   17,   17,   17,   17,   17,
       17,   17,   17,   17,   17,   17,   17,   87,   87,   87,
       87,   87,   87,   87,   87,   87,   87,   87,   87,   87,
       87,   87,   22,   87,    2,   87,   87,   25,   87,   87,
       87,   10,   87,   87,   87,   87,   15,   87,   63,   87,
       17,   17,    2,   17,   17,   17,   17,   17,   17,   10,
       17,   17,   17,   17,   15,   17,   17,   17,   87,   87,

       87,   87,   87,   87,   87,   87,   87,   87,   87,   87,
       87,   87,   87,   87,   46,   87,   58,   87,   23,   24,
       87,   87,   67,   87,   13,   87,   87,   87,   87,   17,
       17,   17,   17,   17,   17,   17,   17,   13,   17,   17,
       17,   17,   87,   87,   87,   87,   87,   87,   40,   87,
       52,   54,   87,   87,   87,   87,   43,   87,   87,   87,
       87,   87,   87,   87,   14,   87,   87,   68,   17,   17,
       17,   17,   14,   17,   17,   17,   87,   28,   87,   87,
       87,   87,   44,   87,   87,   87,   50,   87,   87,   87,
        3,   87,   87,   12,   11,   62,    3,   17,   17,   12,

       11,   17,   87,   87,   29,   87,   87,   87,   30,   87,
       87,   87,   87,   49,   87,   87,   87,   66,   17,   17,
       87,   87,   87,   87,   87,   87,   31,   87,   87,   87,
       87,   87,   87,   17,   87,   87,   87,   87,   87,   33,
       35,   37,   87,   87,   48,   87,   51,   69,   17,   39,
       87,   87,   87,   87,   47,   55,   53,   87,   32,   34,
       36,   38,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    4,    5,    1,    6,    1,    1,    1,
        1,    1,    7,    8,    9,   10,   11,   12,   13,   14,
       15,   16,   17,   18,   19,   20,   19,   21,   22,    1,
        1,    1,    1,    1,   23,   24,   25,   24,   26,   24,
       21,   21,   21,   21,   21,   21,   21,   21,   21,   27,
       21,   28,   21,   21,   21,   21,   21,   29,   21,   21,
       30,    1,   31,    1,   32,    1,   33,   34,   35,   36,

       37,   38,   39,   40,   41,   42,   43,   44,   45,   46,
       47,   48,   49,   50,   51,   52,   53,   54,   55,   56,
       57,   58,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[59] =
    {   0,
        1,    2,    3,    1,    1,    4,    2,    5,    4,    4,
        2,    6,    6,    6,    6,    6,    6,    6,    6,    6,
        4,    1,    4,    4,    4,    4,    4,    4,    4,    2,
        2,    2,    4,    4,    4,    4,    4,    4,    4,    4,
        4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
        4,    4,    4,    4,    4,    4,    4,    4
    } ;

static yyconst flex_int16_t yy_base[570] =
    {   0,
        0,    0,   58,    0,   84,   85,  123,  161, 1553, 1554,
     1550, 1554, 1547,    0,    0,  198, 1554,  244,  293, 1542,
     1554, 1554, 1554,  114,  111,  112,  115,  118,  124,  131,
      125,  133,  132,  134,  113,  140,  156,  126, 1547,    0,
      298,    0,    0,  350,  405,  197, 1554,  436,  146,  194,
      199,  107,  229,  231,  232,  234,  246,  249,  251,  282,
      338,  301,  309,  127,  144,  137,  342, 1512,  364,  332,
      185,  346,  241,  352,  421,  395, 1545, 1542, 1554,    0,
        0,  313, 1554, 1554, 1554, 1554, 1554,  104, 1493, 1554,
      127, 1554, 1554, 1554, 1536,    0,  475,  162,  193,  246,

      209,  388,  275,  245,  386,  378,  382,  202,  288,  379,
      401,  432,  230,  307,  397,  296,  403,  438,  407,  446,
     1541,    0,  439,    0,    0,    0,    0,    0,  401, 1490,
        0,  409,    0,    0,    0,  434,    0,  506,  509,  518,
      510,  511,  525,  530,  532,  541,  543,  548,  555,  557,
      569,  566,  577,  574,  585,  586,  597,  599,  608,  606,
      613,  451,  448,  471,  290,  455,  467,  456,  469,  611,
      620,  453,  544,  470,  526,  611, 1554, 1554, 1485, 1554,
     1554,    0, 1532,  527, 1531, 1530,  509,  525,  457,  211,
      603,  616, 1529,  551, 1528,  528, 1527,  608,  630,  389,

      632,  498, 1526,  584,  642,  552,  656,    0,    0, 1477,
        0,    0,    0,  633,  640,  653,  654,  661,  672,  674,
      675,  677,  688,  690,  691,  704,  705,  706,  707,  718,
      739,  727,  730,  732,  741,  746,  748,  669,  684,  667,
      688,  673,  698,  747,  643,  753,  683,  788,  749,  687,
      763,  766, 1554,  775,  781,  783, 1524,  790, 1523,  791,
      793,  792, 1522,  794,  797,  798,  795,  800,  799,  802,
      801,  805,  807,    0,  782,  784,  810,  813,  818,  815,
      827,  830,  842,  843,  844,  856,  857,  869,  872,  871,
      884,  887,  889,  901,  804,  860,  821, 1521,  886,  877,

      864,  890,  892,  926,  934, 1520,  924,  906,  675,  932,
      893,  935,  936,  938, 1519,  905,  940,  943,  944,  946,
      947,  948,  828,  949,  950,  951,  953,  954,  927,  935,
      958,  965,  943,  960,  967,  972,  974,  988,  986,  987,
      999, 1000, 1001, 1002, 1014, 1015, 1027,  957, 1021, 1048,
     1022,  982, 1035, 1041, 1044, 1056, 1060,  207, 1057, 1068,
     1069, 1070, 1518, 1071, 1072, 1073, 1075, 1517, 1076, 1077,
     1082, 1516, 1083, 1081, 1084, 1089, 1515, 1085, 1514, 1091,
     1064, 1079, 1094, 1067, 1097, 1102, 1110, 1117, 1118, 1119,
     1130, 1132, 1133, 1141, 1146, 1149, 1154, 1165, 1094, 1103,

     1090, 1104, 1152, 1144, 1128, 1106,  653, 1163, 1167,  813,
     1175, 1180, 1141, 1185, 1513, 1191, 1512, 1194, 1511, 1510,
     1198, 1196, 1509, 1199, 1508, 1201, 1202, 1205, 1204, 1181,
     1184, 1183, 1196, 1199, 1210, 1207, 1221, 1223, 1224, 1226,
     1235, 1240, 1217, 1257, 1229, 1260, 1271, 1274, 1507, 1275,
     1506, 1505, 1276, 1279, 1087, 1240, 1504, 1280, 1281, 1282,
     1284, 1287, 1289, 1290, 1497, 1292, 1291, 1485, 1265, 1294,
     1299, 1301, 1277, 1312, 1310, 1315, 1310, 1475, 1294, 1351,
     1298, 1300, 1474, 1345, 1361, 1328, 1472, 1318, 1365, 1336,
     1471, 1316, 1349, 1467, 1466, 1464, 1340, 1341, 1342, 1343,

     1354, 1355, 1352, 1367, 1458, 1390,  956, 1395, 1334, 1396,
     1376, 1385, 1388, 1312, 1394, 1397, 1398, 1296, 1377, 1379,
     1408, 1402, 1413, 1416,  879, 1418, 1241, 1410, 1425, 1428,
     1431, 1429, 1432, 1406, 1435, 1437, 1439,  958, 1440, 1139,
     1017,  866, 1441, 1443,  832, 1449,  817,  815, 1422,  717,
     1453, 1459, 1210, 1446,  530,  478,  476, 1461,  394,  319,
      214,  121, 1554, 1484, 1490, 1492, 1495, 1500, 1505
    } ;

static yyconst flex_int16_t yy_def[570] =
    {   0,
      563,    1,  563,    3,    1,    1,    1,    1,  563,  563,
      563,  563,  564,  565,  566,  563,  563,  567,  567,  567,
      563,  563,  563,  567,  567,  567,  567,  567,  567,  567,
      567,  567,  567,  567,  567,  567,  567,  567,  568,  568,
      568,  568,  568,  569,  569,  569,  563,  569,   48,   48,
       48,   48,   48,   48,   48,   48,   48,   48,   48,   48,
       48,   48,  567,  567,  567,  567,  567,   19,  567,  567,
      567,  567,  567,  567,  567,  567,  563,  564,  563,  565,
      566,  563,  563,  563,  563,  563,  563,  563,  563,  563,
      563,  563,  563,  563,  567,   19,   19,  567,  567,  567,

      567,  567,  567,  567,  567,  567,  567,  567,  567,  567,
      567,  567,  567,  567,  567,  567,  567,  567,  567,  567,
      568,  568,  568,  568,  568,  568,  568,  568,  568,  568,
      568,  568,  568,  568,  568,   48,   45,   45,   48,   48,
       48,   48,   48,   48,   48,   48,   48,   48,   48,   48,
       48,   48,   48,   48,   48,   48,   48,   48,   48,   48,
       48,  567,  567,  567,  567,  567,  567,  567,  567,  567,
      567,  567,  567,  567,  567,  563,  563,  563,  563,  563,
      563,   97,  567,  567,  567,  567,  567,  567,  567,  567,
      567,  567,  567,  567,  567,  567,  567,  567,  567,  567,

      567,  567,  567,  567,  567,  567,  568,  568,  568,  568,
      568,  568,  138,   48,   48,   48,   48,   48,   48,   48,
       48,   48,   48,   48,   48,   48,   48,   48,   48,   48,
       48,   48,   48,   48,   48,   48,   48,  567,  567,  567,
      567,  567,  567,  567,  567,  567,  567,  567,  567,  567,
      567,  567,  563,  567,  567,  567,  567,  567,  567,  567,
      567,  567,  567,  567,  567,  567,  567,  567,  567,  567,
      567,  567,  567,  568,   48,   48,   48,   48,   48,   48,
       48,   48,   48,   48,   48,   48,   48,   48,   48,   48,
       48,   48,   48,   48,  567,  567,  567,  567,  567,  567,

      567,  567,  567,  567,  567,  567,  567,  567,  567,  567,
      567,  567,  567,  567,  567,  567,  567,  567,  567,  567,
      567,  567,  567,  567,  567,  567,  567,  567,   48,   48,
       48,   48,   48,   48,   48,   48,   48,   48,   48,   48,
       48,   48,   48,   48,   48,   48,   48,  567,  567,  567,
      567,  567,  567,  567,  567,  567,  567,  567,  567,  567,
      567,  567,  567,  567,  567,  567,  567,  567,  567,  567,
      567,  567,  567,  567,  567,  567,  567,  567,  567,  567,
       48,   48,   48,   48,   48,   48,   48,   48,   48,   48,
       48,   48,   48,   48,   48,   48,   48,   48,  567,  567,

      567,  567,  567,  567,  567,  567,  567,  567,  567,  567,
      567,  567,  567,  567,  567,  567,  567,  567,  567,  567,
      567,  567,  567,  567,  567,  567,  567,  567,  567,   48,
       48,   48,   48,   48,   48,   48,   48,   48,   48,   48,
       48,   48,  567,  567,  567,  567,  567,  567,  567,  567,
      567,  567,  567,  567,  567,  567,  567,  567,  567,  567,
      567,  567,  567,  567,  567,  567,  567,  567,   48,   48,
       48,   48,   48,   48,   48,   48,  567,  567,  567,  567,
      567,  567,  567,  567,  567,  567,  567,  567,  567,  567,
      567,  567,  567,  567,  567,  567,   48,   48,   48,   48,

       48,   48,  567,  567,  567,  567,  567,  567,  567,  567,
      567,  567,  567,  567,  567,  567,  567,  567,   48,   48,
      567,  567,  567,  567,  567,  567,  567,  567,  567,  567,
      567,  567,  567,   48,  567,  567,  567,  567,  567,  567,
      567,  567,  567,  567,  567,  567,  567,  567,   48,  567,
      567,  567,  567,  567,  567,  567,  567,  567,  567,  567,
      567,  567,    0,  563,  563,  563,  563,  563,  563
    } ;

static yyconst flex_int16_t yy_nxt[1613] =
    {   0,
       10,   11,   12,   13,   14,   10,   10,   15,   16,   10,
       17,   18,   19,   19,   19,   19,   19,   19,   19,   19,
       20,   21,   20,   20,   20,   20,   20,   20,   20,   22,
       23,   10,   24,   25,   20,   26,   27,   28,   29,   20,
       30,   20,   20,   31,   20,   32,   33,   20,   34,   35,
       36,   37,   20,   20,   20,   20,   20,   38,   10,   39,
       40,   13,   14,   10,   10,   15,   41,   42,   43,   44,
       45,   45,   45,   45,   45,   45,   45,   45,   46,   47,
       46,   46,   46,   46,   46,   46,   46,   22,   23,   42,
       48,   49,   46,   50,   51,   52,   53,   46,   54,   46,

       46,   55,   46,   56,   57,   46,   58,   59,   60,   61,
       46,   46,   46,   46,   46,   62,   63,   63,  563,  563,
      563,  563,  563,   64,   64,  563,   65,   65,  563,   66,
       66,  563,  563,  563,  563,   67,   67,   68,  563,  563,
      563,  563,  136,  177,  563,  113,  136,  563,  102,   98,
      147,  563,  136,   99,  178,   69,   70,   71,   72,  100,
      107,  106,  120,  563,  103,  104,  180,  101,   73,  563,
      105,  163,   74,   75,   76,   68,  114,  181,  108,  110,
      164,  136,  109,  110,  111,  136,  112,  115,  116,  165,
      117,  136,  563,   69,   70,   71,   72,  183,  122,  122,

      563,  184,  142,  122,  563,  118,   73,  122,  119,  563,
       74,   75,   76,   82,  563,   82,  563,  170,  563,  258,
       83,  563,   84,   85,   86,   87,  122,  122,  122,  136,
      143,   88,   89,  136,  136,   90,  194,  563,  136,  136,
      412,   91,   92,   82,  136,  186,  144,   93,  563,  145,
       94,   81,  563,  563,  146,   96,   96,   96,   96,   96,
       96,   96,   96,   96,  136,  148,  136,  136,  136,  136,
      136,  136,   97,  136,  136,  199,  136,  136,  149,  136,
      151,  136,  563,  154,  136,  136,  136,  110,  136,  150,
      136,  136,  190,  172,  136,  563,  136,  563,  152,   97,

       81,  153,  185,  563,   96,   96,   96,   96,   96,   96,
       96,   96,   96,  123,  563,  123,  563,  136,  155,  189,
      124,  136,  125,  126,  127,  128,  563,  136,  176,  156,
      176,  129,  130,  241,  202,  131,  136,  161,  195,  563,
      136,  132,  133,  123,   98,  162,  136,  134,   99,  563,
      135,  122,  122,  563,  100,  200,  122,   81,  176,  563,
      122,  137,  137,  137,  137,  137,  137,  137,  137,  137,
      157,  563,  158,  136,  116,  169,  166,  136,  138,  122,
      122,  122,  171,  136,  113,  563,  563,  159,  101,  563,
      160,  118,  173,  563,  119,  563,  563,  265,  103,   98,

      168,  563,  563,   99,  563,  138,  122,  122,  563,  100,
      563,  122,   81,  196,  563,  122,  137,  137,  137,  137,
      137,  137,  137,  137,  137,  187,  191,  116,  563,  117,
      192,  188,  201,  193,  122,  122,  122,  122,  122,  563,
      208,  197,  122,  563,  118,  563,  122,  119,  211,  175,
      203,  209,  205,  563,  207,  563,  207,  114,  563,  212,
      563,  174,  563,  563,  563,  122,  122,  122,  115,  136,
      204,  139,  198,  136,  563,  140,  563,  563,  563,  136,
      239,  141,  563,  563,  207,  563,  182,  182,  182,  182,
      182,  182,  182,  182,  182,  206,  249,  182,  182,  182,

      182,  238,  242,  243,  257,  563,  244,  182,  182,  182,
      182,  182,  182,  563,  251,  245,  563,  213,  213,  213,
      213,  213,  213,  213,  213,  213,  215,  240,  213,  213,
      213,  213,  563,  563,  563,  563,  270,  563,  213,  213,
      213,  213,  213,  213,  214,  136,  136,  217,  136,  136,
      136,  563,  255,  136,  136,  136,  136,  136,  563,  563,
      136,  256,  218,  136,  136,  136,  216,  136,  219,  136,
      136,  136,  252,  254,  220,  136,  136,  136,  136,  221,
      136,  222,  136,  136,  262,  250,  136,  136,  136,  225,
      136,  563,  136,  136,  136,  223,  136,  261,  273,  224,

      136,  136,  136,  227,  136,  136,  228,  226,  136,  136,
      563,  136,  136,  136,  136,  563,  136,  229,  563,  230,
      136,  232,  136,  563,  136,  136,  176,  563,  176,  271,
      136,  136,  136,  231,  136,  233,  136,  563,  136,  563,
      235,  136,  136,  136,  136,  136,  234,  136,  136,  563,
      563,  236,  136,  136,  259,  246,  176,  187,  136,  263,
      563,  247,  237,  188,  266,  264,  260,  267,  136,  268,
      248,  207,  136,  207,  563,  136,  563,  295,  136,  136,
      563,  299,  563,  279,  269,  136,  275,  272,  136,  136,
      563,  563,  136,  136,  563,  563,  136,  302,  136,  136,

      136,  207,  452,  297,  276,  563,  136,  136,  277,  136,
      136,  136,  136,  136,  136,  362,  136,  136,  296,  136,
      136,  278,  136,  136,  563,  136,  136,  136,  280,  136,
      136,  298,  307,  136,  304,  136,  136,  282,  281,  136,
      136,  136,  136,  136,  136,  136,  136,  286,  300,  136,
      136,  136,  136,  285,  563,  301,  563,  136,  284,  287,
      563,  283,  288,  136,  289,  136,  136,  136,  291,  136,
      563,  136,  136,  563,  136,  136,  136,  136,  136,  290,
      136,  136,  563,  136,  136,  136,  292,  136,  563,  303,
      563,  293,  306,  136,  294,  563,  305,  563,  563,  563,

      563,  563,  563,  309,  563,  563,  563,  563,  563,  563,
      308,  563,  563,  311,  563,  328,  330,  136,  310,  136,
      563,  136,  563,  136,  563,  329,  317,  136,  563,  136,
      315,  321,  455,  320,  312,  563,  313,  316,  325,  563,
      318,  327,  314,  323,  319,  136,  324,  322,  136,  136,
      136,  326,  136,  136,  136,  136,  350,  136,  136,  348,
      136,  331,  136,  136,  332,  136,  334,  563,  349,  136,
      333,  563,  136,  563,  335,  136,  336,  136,  136,  136,
      375,  136,  136,  136,  563,  352,  563,  136,  136,  136,
      337,  136,  339,  563,  541,  136,  136,  563,  353,  563,

      563,  136,  136,  338,  136,  340,  136,  136,  136,  347,
      136,  136,  563,  563,  136,  342,  136,  136,  343,  136,
      344,  341,  136,  136,  136,  346,  136,  354,  136,  136,
      351,  563,  136,  563,  136,  355,  136,  345,  356,  563,
      136,  563,  563,  563,  364,  563,  136,  563,  357,  361,
      563,  563,  368,  563,  563,  563,  563,  563,  563,  360,
      563,  563,  381,  563,  563,  563,  136,  363,  358,  359,
      136,  365,  136,  367,  136,  525,  371,  553,  385,  366,
      136,  372,  136,  369,  376,  377,  382,  370,  136,  563,
      373,  399,  374,  136,  383,  136,  379,  136,  378,  136,

      136,  380,  136,  136,  136,  136,  136,  136,  384,  136,
      136,  136,  136,  136,  386,  387,  405,  136,  388,  136,
      389,  390,  136,  136,  563,  136,  136,  136,  563,  563,
      391,  136,  136,  136,  136,  136,  394,  395,  136,  136,
      136,  136,  563,  392,  136,  136,  136,  136,  563,  136,
      136,  563,  393,  136,  136,  563,  403,  404,  397,  136,
      136,  396,  136,  563,  563,  400,  136,  563,  406,  410,
      401,  402,  136,  411,  398,  563,  563,  563,  563,  563,
      563,  408,  563,  563,  563,  422,  407,  409,  563,  563,
      563,  563,  563,  413,  563,  486,  563,  563,  563,  136,

      414,  563,  432,  136,  418,  415,  136,  417,  419,  136,
      563,  563,  136,  563,  136,  430,  421,  423,  136,  424,
      416,  427,  420,  429,  136,  435,  431,  443,  425,  136,
      445,  428,  136,  136,  426,  563,  136,  136,  444,  136,
      451,  136,  136,  446,  433,  136,  563,  136,  563,  136,
      434,  563,  136,  436,  136,  136,  136,  136,  136,  563,
      449,  450,  136,  136,  136,  136,  437,  136,  136,  136,
      563,  136,  136,  440,  563,  136,  136,  136,  136,  438,
      136,  136,  563,  439,  136,  136,  136,  563,  136,  136,
      458,  136,  563,  136,  136,  441,  447,  442,  563,  136,

      136,  563,  448,  563,  136,  563,  563,  454,  563,  563,
      136,  563,  563,  453,  457,  456,  136,  563,  136,  136,
      136,  459,  136,  136,  563,  560,  136,  469,  136,  136,
      460,  136,  462,  470,  136,  136,  563,  461,  136,  468,
      465,  136,  136,  463,  136,  136,  136,  563,  563,  136,
      464,  477,  136,  466,  467,  136,  136,  471,  136,  136,
      136,  136,  136,  473,  563,  136,  136,  563,  136,  136,
      136,  136,  472,  478,  136,  476,  479,  474,  563,  136,
      136,  563,  563,  563,  475,  136,  563,  563,  563,  563,
      490,  563,  480,  487,  563,  492,  563,  563,  563,  563,

      136,  563,  498,  563,  136,  563,  481,  563,  497,  483,
      136,  485,  136,  482,  509,  484,  136,  563,  503,  563,
      488,  493,  136,  563,  489,  563,  494,  491,  495,  136,
      504,  499,  510,  136,  136,  563,  136,  500,  136,  136,
      136,  563,  496,  563,  136,  136,  136,  136,  501,  136,
      136,  136,  563,  511,  136,  136,  563,  136,  563,  563,
      136,  502,  513,  505,  506,  507,  517,  508,  563,  512,
      516,  514,  563,  515,  563,  136,  136,  520,  136,  136,
      136,  136,  136,  563,  518,  136,  136,  136,  136,  136,
      136,  519,  563,  136,  136,  563,  521,  563,  523,  136,

      136,  563,  563,  563,  563,  563,  524,  526,  527,  563,
      528,  522,  136,  534,  136,  563,  136,  563,  136,  529,
      563,  530,  136,  563,  136,  563,  537,  538,  531,  539,
      532,  542,  563,  540,  533,  563,  563,  536,  563,  563,
      535,  136,  563,  543,  563,  136,  563,  563,  563,  551,
      563,  136,  554,  563,  549,  552,  563,  136,  544,  561,
      563,  136,  545,  547,  546,  563,  563,  136,  563,  550,
      558,  563,  562,  563,  563,  555,  559,  556,  563,  563,
      548,  563,  563,  557,   78,   78,   78,   78,   78,   78,
       80,   80,  563,   80,   80,   80,   81,   81,   95,   95,

       95,  122,  122,  122,  563,  122,  136,  136,  136,  136,
      136,  563,  563,  563,  563,  563,  563,  563,  563,  563,
      563,  563,  563,  563,  563,  563,  563,  563,  563,  563,
      563,  563,  274,  563,  563,  563,  563,  563,  563,  563,
      253,  210,  121,  563,  179,   79,   77,  167,  121,  563,
       79,   77,  563,    9,  563,  563,  563,  563,  563,  563,
      563,  563,  563,  563,  563,  563,  563,  563,  563,  563,
      563,  563,  563,  563,  563,  563,  563,  563,  563,  563,
      563,  563,  563,  563,  563,  563,  563,  563,  563,  563,
      563,  563,  563,  563,  563,  563,  563,  563,  563,  563,

      563,  563,  563,  563,  563,  563,  563,  563,  563,  563,
      563,  563
    } ;

static yyconst flex_int16_t yy_chk[1613] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,

        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    5,    6,   25,   26,
       35,   24,   27,    5,    6,   28,    5,    6,  562,    5,
        6,   29,   31,   38,   64,    5,    6,    7,   30,   33,
       32,   34,   52,   88,   66,   35,   52,   36,   26,   24,
       52,   65,   52,   24,   88,    7,    7,    7,    7,   24,
       29,   28,   38,   37,   26,   27,   91,   25,    7,   98,
       27,   64,    7,    7,    7,    8,   36,   91,   30,   32,
       65,   49,   31,   66,   33,   49,   34,   36,   37,   66,
       37,   49,   71,    8,    8,    8,    8,   98,   46,   46,

       99,   99,   49,   46,   46,   37,    8,   46,   37,  108,
        8,    8,    8,   16,  358,   16,  101,   71,  190,  190,
       16,  561,   16,   16,   16,   16,   46,   46,   46,   50,
       50,   16,   16,   50,   51,   16,  108,  113,   51,   50,
      358,   16,   16,   16,   51,  101,   50,   16,   73,   51,
       16,   18,  104,  100,   51,   18,   18,   18,   18,   18,
       18,   18,   18,   18,   53,   53,   54,   55,   53,   56,
       54,   55,   18,   56,   53,  113,   54,   55,   54,   56,
       56,   57,  103,   59,   58,   57,   59,   73,   58,   55,
       59,   57,  104,   73,   58,  109,   59,  165,   57,   18,

       19,   58,  100,  116,   19,   19,   19,   19,   19,   19,
       19,   19,   19,   41,  114,   41,   63,   60,   60,  103,
       41,   60,   41,   41,   41,   41,  560,   60,   82,   60,
       82,   41,   41,  165,  116,   41,   62,   62,  109,   70,
       62,   41,   41,   41,   63,   63,   62,   41,   63,   67,
       41,   44,   44,   72,   63,  114,   44,   44,   82,   74,
       44,   44,   44,   44,   44,   44,   44,   44,   44,   44,
       61,   69,   61,   61,   67,   70,   67,   61,   44,   44,
       44,   44,   72,   61,   74,  106,  110,   61,   70,  107,
       61,   67,   74,  105,   67,  102,  200,  200,   72,   69,

       69,  559,   76,   69,  115,   44,   45,   45,  111,   69,
      117,   45,   45,  110,  119,   45,   45,   45,   45,   45,
       45,   45,   45,   45,   45,  102,  105,   76,   75,   76,
      106,  102,  115,  107,   45,   45,   45,   48,   48,  112,
      129,  111,   48,   48,   76,  118,   48,   76,  132,   76,
      117,  129,  119,  120,  123,  163,  123,   75,  162,  132,
      172,   75,  166,  168,  189,   48,   48,   48,   75,  136,
      118,   48,  112,  136,  167,   48,  169,  174,  164,  136,
      163,   48,   97,  557,  123,  556,   97,   97,   97,   97,
       97,   97,   97,   97,   97,  120,  172,   97,   97,   97,

       97,  162,  166,  167,  189,  202,  168,   97,   97,   97,
       97,   97,   97,  138,  174,  169,  187,  138,  138,  138,
      138,  138,  138,  138,  138,  138,  140,  164,  138,  138,
      138,  138,  188,  175,  184,  196,  202,  555,  138,  138,
      138,  138,  138,  138,  139,  141,  142,  142,  139,  141,
      142,  173,  187,  140,  139,  141,  142,  140,  194,  206,
      143,  188,  143,  140,  143,  144,  141,  145,  143,  144,
      143,  145,  175,  184,  144,  144,  146,  145,  147,  145,
      146,  146,  147,  148,  196,  173,  146,  148,  147,  149,
      149,  204,  150,  148,  149,  147,  150,  194,  206,  148,

      149,  152,  150,  151,  151,  152,  152,  150,  151,  154,
      191,  152,  153,  154,  151,  198,  153,  153,  170,  154,
      155,  156,  153,  192,  155,  156,  176,  171,  176,  204,
      155,  156,  157,  155,  158,  157,  157,  199,  158,  201,
      159,  160,  157,  159,  158,  160,  158,  159,  161,  205,
      245,  160,  161,  159,  191,  170,  176,  171,  161,  198,
      407,  170,  161,  171,  201,  199,  192,  201,  214,  201,
      171,  207,  214,  207,  240,  215,  238,  238,  214,  215,
      242,  242,  309,  221,  201,  215,  215,  205,  216,  217,
      247,  239,  216,  217,  250,  241,  218,  245,  216,  217,

      218,  207,  407,  240,  218,  243,  218,  219,  219,  220,
      221,  219,  222,  220,  221,  309,  222,  219,  239,  220,
      221,  220,  222,  223,  550,  224,  225,  223,  222,  224,
      225,  241,  250,  223,  247,  224,  225,  225,  223,  226,
      227,  228,  229,  226,  227,  228,  229,  231,  243,  226,
      227,  228,  229,  230,  244,  244,  249,  230,  229,  232,
      246,  227,  232,  230,  232,  233,  232,  234,  233,  233,
      251,  234,  232,  252,  231,  233,  235,  234,  231,  232,
      235,  236,  254,  237,  231,  236,  235,  237,  255,  246,
      256,  236,  249,  237,  237,  248,  248,  258,  260,  262,

      261,  264,  267,  252,  265,  266,  269,  268,  271,  270,
      251,  295,  272,  255,  273,  273,  276,  275,  254,  276,
      410,  275,  548,  276,  547,  275,  262,  275,  297,  276,
      260,  267,  410,  266,  256,  323,  258,  261,  270,  545,
      264,  272,  258,  268,  265,  277,  269,  267,  278,  277,
      280,  271,  278,  279,  280,  277,  297,  279,  278,  295,
      280,  277,  281,  279,  279,  282,  281,  296,  296,  282,
      279,  301,  281,  542,  282,  282,  283,  283,  284,  285,
      323,  283,  284,  285,  300,  300,  525,  283,  284,  285,
      285,  286,  287,  299,  525,  286,  287,  302,  301,  303,

      311,  286,  287,  286,  288,  288,  290,  289,  288,  294,
      290,  289,  316,  308,  288,  289,  290,  289,  290,  291,
      291,  288,  292,  291,  293,  293,  292,  302,  293,  291,
      299,  307,  292,  304,  293,  303,  294,  292,  304,  310,
      294,  305,  312,  313,  311,  314,  294,  317,  305,  308,
      318,  319,  316,  320,  321,  322,  324,  325,  326,  307,
      327,  328,  329,  507,  348,  538,  329,  310,  305,  305,
      330,  312,  329,  314,  330,  507,  319,  538,  333,  313,
      330,  320,  333,  317,  324,  325,  330,  318,  333,  352,
      321,  348,  322,  331,  331,  334,  327,  331,  326,  334,

      332,  328,  335,  331,  332,  334,  335,  336,  332,  337,
      332,  336,  335,  337,  335,  336,  352,  336,  337,  337,
      338,  339,  340,  338,  541,  339,  340,  338,  349,  351,
      340,  339,  340,  338,  341,  342,  343,  344,  341,  342,
      343,  344,  353,  341,  341,  342,  343,  344,  354,  345,
      346,  355,  342,  345,  346,  350,  350,  351,  346,  345,
      346,  345,  347,  356,  359,  349,  347,  357,  353,  356,
      349,  349,  347,  357,  347,  360,  361,  362,  364,  365,
      366,  354,  367,  369,  370,  370,  353,  355,  374,  371,
      373,  375,  378,  359,  455,  455,  376,  401,  380,  381,

      360,  399,  384,  381,  365,  361,  384,  364,  366,  381,
      400,  402,  384,  406,  382,  382,  369,  371,  382,  373,
      362,  376,  367,  380,  382,  388,  383,  399,  374,  383,
      401,  378,  385,  383,  375,  405,  385,  386,  400,  383,
      406,  386,  385,  402,  385,  387,  540,  386,  413,  387,
      387,  404,  388,  389,  390,  387,  388,  389,  390,  403,
      404,  405,  388,  389,  390,  391,  391,  392,  393,  391,
      408,  392,  393,  394,  409,  391,  394,  392,  393,  392,
      394,  395,  411,  393,  396,  395,  394,  412,  396,  397,
      413,  395,  414,  397,  396,  396,  403,  398,  416,  397,

      398,  418,  403,  422,  398,  421,  424,  409,  426,  427,
      398,  429,  428,  408,  412,  411,  430,  553,  432,  431,
      430,  414,  432,  431,  443,  553,  430,  431,  432,  431,
      416,  433,  421,  434,  434,  433,  445,  418,  434,  429,
      426,  433,  436,  422,  434,  435,  436,  456,  527,  435,
      424,  443,  436,  427,  428,  435,  437,  435,  438,  439,
      437,  440,  438,  439,  444,  440,  437,  446,  438,  439,
      441,  440,  437,  444,  441,  442,  445,  440,  447,  442,
      441,  448,  450,  453,  441,  442,  454,  458,  459,  460,
      460,  461,  446,  456,  462,  462,  463,  464,  467,  466,

      469,  479,  470,  518,  469,  481,  447,  482,  469,  450,
      469,  454,  473,  448,  481,  453,  473,  477,  477,  514,
      458,  463,  473,  492,  459,  488,  464,  461,  466,  470,
      479,  471,  482,  470,  471,  486,  472,  472,  471,  470,
      472,  509,  467,  490,  471,  475,  472,  474,  474,  475,
      476,  474,  484,  484,  476,  475,  493,  474,  480,  503,
      476,  475,  486,  480,  480,  480,  492,  480,  485,  485,
      490,  488,  489,  489,  504,  497,  498,  499,  500,  497,
      498,  499,  500,  511,  493,  497,  498,  499,  500,  501,
      502,  498,  512,  501,  502,  513,  503,  506,  506,  501,

      502,  515,  508,  510,  516,  517,  506,  508,  510,  522,
      511,  504,  519,  519,  520,  521,  519,  528,  520,  512,
      523,  513,  519,  524,  520,  526,  523,  523,  515,  523,
      516,  526,  529,  524,  517,  530,  532,  522,  531,  533,
      521,  534,  535,  528,  536,  534,  537,  539,  543,  536,
      544,  534,  539,  554,  534,  537,  546,  549,  529,  554,
      551,  549,  530,  532,  531,  505,  552,  549,  558,  535,
      551,  496,  558,  495,  494,  543,  552,  544,  491,  487,
      533,  483,  478,  546,  564,  564,  564,  564,  564,  564,
      565,  565,  468,  565,  565,  565,  566,  566,  567,  567,

      567,  568,  568,  568,  465,  568,  569,  569,  569,  569,
      569,  457,  452,  451,  449,  425,  423,  420,  419,  417,
      415,  379,  377,  372,  368,  363,  315,  306,  298,  263,
      259,  257,  210,  203,  197,  195,  193,  186,  185,  183,
      179,  130,  121,   95,   89,   78,   77,   68,   39,   20,
       13,   11,    9,  563,  563,  563,  563,  563,  563,  563,
      563,  563,  563,  563,  563,  563,  563,  563,  563,  563,
      563,  563,  563,  563,  563,  563,  563,  563,  563,  563,
      563,  563,  563,  563,  563,  563,  563,  563,  563,  563,
      563,  563,  563,  563,  563,  563,  563,  563,  563,  563,

      563,  563,  563,  563,  563,  563,  563,  563,  563,  563,
      563,  563
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int setkeyyy_flex_debug;
int setkeyyy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
static int yy_more_flag = 0;
static int yy_more_len = 0;
#define yymore() ((yy_more_flag) = 1)
#define YY_MORE_ADJ (yy_more_len)
#define YY_RESTORE_YY_MORE_OFFSET
char *setkeyyytext;
#line 1 "../../ipsec-tools/src/setkey/token.l"
/*	$NetBSD: token.l,v 1.15 2010/06/04 13:06:03 vanhu Exp $	*/
/*	$KAME: token.l,v 1.44 2003/10/21 07:20:58 itojun Exp $	*/
/*
 * Copyright (C) 1995, 1996, 1997, 1998, and 1999 WIDE Project.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the project nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE PROJECT AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE PROJECT OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
#line 35 "../../ipsec-tools/src/setkey/token.l"

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <sys/types.h>
#include <sys/param.h>
#include <sys/socket.h>
#include <net/pfkeyv2.h>
#include <netinet/in.h>
#include PATH_IPSEC_H

#include <stdlib.h>
#include <limits.h>
#include <string.h>
#include <unistd.h>
#include <errno.h>
#include <netdb.h>

#include "vchar.h"
#if defined(__NetBSD__) || defined(__FreeBSD__) || defined(__linux__) || \
(defined(__APPLE__) && defined(__MACH__))
#include "parse.h"
#else
#include "y.tab.h"
#endif

#include "extern.h"

/* make the code compile on *BSD-current */
#ifndef SADB_X_AALG_SHA2_256
#define SADB_X_AALG_SHA2_256	(-1)
#endif
#ifndef SADB_X_AALG_SHA2_384
#define SADB_X_AALG_SHA2_384	(-1)
#endif
#ifndef SADB_X_AALG_SHA2_512
#define SADB_X_AALG_SHA2_512	(-1)
#endif
#ifndef SADB_X_AALG_RIPEMD160HMAC
#define SADB_X_AALG_RIPEMD160HMAC	(-1)
#endif
#ifndef SADB_X_AALG_AES_XCBC_MAC
#define SADB_X_AALG_AES_XCBC_MAC	(-1)
#endif
#ifndef SADB_X_EALG_TWOFISHCBC
#define SADB_X_EALG_TWOFISHCBC	(-1)
#endif
#ifndef SADB_X_EALG_AESCTR
#define SADB_X_EALG_AESCTR	(-1)
#endif
#if defined(SADB_X_EALG_AES) && ! defined(SADB_X_EALG_AESCBC)
#define SADB_X_EALG_AESCBC  SADB_X_EALG_AES
#endif
/* common section */

#define YY_NO_INPUT 1
#line 1114 "<stdout>"

#define INITIAL 0
#define S_PL 1
#define S_AUTHALG 2
#define S_ENCALG 3

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int setkeyyylex_destroy (void );

int setkeyyyget_debug (void );

void setkeyyyset_debug (int debug_flag  );

YY_EXTRA_TYPE setkeyyyget_extra (void );

void setkeyyyset_extra (YY_EXTRA_TYPE user_defined  );

FILE *setkeyyyget_in (void );

void setkeyyyset_in  (FILE * in_str  );

FILE *setkeyyyget_out (void );

void setkeyyyset_out  (FILE * out_str  );

yy_size_t setkeyyyget_leng (void );

char *setkeyyyget_text (void );

int setkeyyyget_lineno (void );

void setkeyyyset_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int setkeyyywrap (void );
#else
extern int setkeyyywrap (void );
#endif
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( setkeyyytext, setkeyyyleng, 1, setkeyyyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( setkeyyyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( setkeyyyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, setkeyyyin))==0 && ferror(setkeyyyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(setkeyyyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int setkeyyylex (void);

#define YY_DECL int setkeyyylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after setkeyyytext and setkeyyyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
#line 115 "../../ipsec-tools/src/setkey/token.l"



#line 1301 "<stdout>"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! setkeyyyin )
			setkeyyyin = stdin;

		if ( ! setkeyyyout )
			setkeyyyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			setkeyyyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				setkeyyy_create_buffer(setkeyyyin,YY_BUF_SIZE );
		}

		setkeyyy_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		(yy_more_len) = 0;
		if ( (yy_more_flag) )
			{
			(yy_more_len) = (yy_c_buf_p) - (yytext_ptr);
			(yy_more_flag) = 0;
			}
		yy_cp = (yy_c_buf_p);

		/* Support of setkeyyytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 564 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 1554 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 118 "../../ipsec-tools/src/setkey/token.l"
{ return(ADD); }
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 119 "../../ipsec-tools/src/setkey/token.l"
{ return(DELETE); }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 120 "../../ipsec-tools/src/setkey/token.l"
{ return(DELETEALL); }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 121 "../../ipsec-tools/src/setkey/token.l"
{ return(GET); }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 122 "../../ipsec-tools/src/setkey/token.l"
{ return(FLUSH); }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 123 "../../ipsec-tools/src/setkey/token.l"
{ return(DUMP); }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 124 "../../ipsec-tools/src/setkey/token.l"
{ return(EXIT); }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 125 "../../ipsec-tools/src/setkey/token.l"
{ return(EXIT); }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 126 "../../ipsec-tools/src/setkey/token.l"
{ return(EXIT); }
	YY_BREAK
/* for management SPD */
case 10:
YY_RULE_SETUP
#line 129 "../../ipsec-tools/src/setkey/token.l"
{ return(SPDADD); }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 130 "../../ipsec-tools/src/setkey/token.l"
{ return(SPDUPDATE); }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 131 "../../ipsec-tools/src/setkey/token.l"
{ return(SPDDELETE); }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 132 "../../ipsec-tools/src/setkey/token.l"
{ return(SPDDUMP); }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 133 "../../ipsec-tools/src/setkey/token.l"
{ return(SPDFLUSH); }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 134 "../../ipsec-tools/src/setkey/token.l"
{ return(TAGGED); }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 135 "../../ipsec-tools/src/setkey/token.l"
{ BEGIN S_PL; return(F_POLICY); }
	YY_BREAK
case 17:
/* rule 17 can match eol */
YY_RULE_SETUP
#line 136 "../../ipsec-tools/src/setkey/token.l"
{
			yymore();

			/* count up for nl */
			    {
				char *p;
				for (p = setkeyyytext; *p != '\0'; p++)
					if (*p == '\n')
						lineno++;
			    }

			yylval.val.len = strlen(setkeyyytext);
			yylval.val.buf = strdup(setkeyyytext);
			if (!yylval.val.buf)
				yyfatal("insufficient memory");

			return(PL_REQUESTS);
		}
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 154 "../../ipsec-tools/src/setkey/token.l"
{ BEGIN INITIAL; return(EOT); }
	YY_BREAK
/* address resolution flags */
case 19:
YY_RULE_SETUP
#line 157 "../../ipsec-tools/src/setkey/token.l"
{
			yylval.val.len = strlen(setkeyyytext);
			yylval.val.buf = strdup(setkeyyytext);
			if (!yylval.val.buf)
				yyfatal("insufficient memory");
			return(F_AIFLAGS);
		}
	YY_BREAK
/* security protocols */
case 20:
YY_RULE_SETUP
#line 166 "../../ipsec-tools/src/setkey/token.l"
{ yylval.num = 0; return(PR_AH); }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 167 "../../ipsec-tools/src/setkey/token.l"
{ yylval.num = 0; return(PR_ESP); }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 168 "../../ipsec-tools/src/setkey/token.l"
{ yylval.num = 1; return(PR_AH); }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 169 "../../ipsec-tools/src/setkey/token.l"
{ yylval.num = 1; return(PR_ESP); }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 170 "../../ipsec-tools/src/setkey/token.l"
{ yylval.num = 0; return(PR_ESPUDP); }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 171 "../../ipsec-tools/src/setkey/token.l"
{ yylval.num = 0; return(PR_IPCOMP); }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 172 "../../ipsec-tools/src/setkey/token.l"
{ 
			yylval.num = 0; return(PR_TCP); 
		}
	YY_BREAK
/* authentication alogorithm */
case 27:
YY_RULE_SETUP
#line 177 "../../ipsec-tools/src/setkey/token.l"
{ BEGIN S_AUTHALG; return(F_AUTH); }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 178 "../../ipsec-tools/src/setkey/token.l"
{ yylval.num = SADB_AALG_MD5HMAC; BEGIN INITIAL; return(ALG_AUTH); }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 179 "../../ipsec-tools/src/setkey/token.l"
{ yylval.num = SADB_AALG_SHA1HMAC; BEGIN INITIAL; return(ALG_AUTH); }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 180 "../../ipsec-tools/src/setkey/token.l"
{ yylval.num = SADB_X_AALG_MD5; BEGIN INITIAL; return(ALG_AUTH); }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 181 "../../ipsec-tools/src/setkey/token.l"
{ yylval.num = SADB_X_AALG_SHA; BEGIN INITIAL; return(ALG_AUTH); }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 182 "../../ipsec-tools/src/setkey/token.l"
{ yylval.num = SADB_X_AALG_SHA2_256; BEGIN INITIAL; return(ALG_AUTH); }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 183 "../../ipsec-tools/src/setkey/token.l"
{ yylval.num = SADB_X_AALG_SHA2_256; BEGIN INITIAL; return(ALG_AUTH); }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 184 "../../ipsec-tools/src/setkey/token.l"
{ yylval.num = SADB_X_AALG_SHA2_384; BEGIN INITIAL; return(ALG_AUTH); }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 185 "../../ipsec-tools/src/setkey/token.l"
{ yylval.num = SADB_X_AALG_SHA2_384; BEGIN INITIAL; return(ALG_AUTH); }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 186 "../../ipsec-tools/src/setkey/token.l"
{ yylval.num = SADB_X_AALG_SHA2_512; BEGIN INITIAL; return(ALG_AUTH); }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 187 "../../ipsec-tools/src/setkey/token.l"
{ yylval.num = SADB_X_AALG_SHA2_512; BEGIN INITIAL; return(ALG_AUTH); }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 188 "../../ipsec-tools/src/setkey/token.l"
{ yylval.num = SADB_X_AALG_RIPEMD160HMAC; BEGIN INITIAL; return(ALG_AUTH); }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 189 "../../ipsec-tools/src/setkey/token.l"
{ yylval.num = SADB_X_AALG_AES_XCBC_MAC; BEGIN INITIAL; return(ALG_AUTH); }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 190 "../../ipsec-tools/src/setkey/token.l"
{ 
#ifdef SADB_X_AALG_TCP_MD5
				yylval.num = SADB_X_AALG_TCP_MD5; 
				BEGIN INITIAL; 
				return(ALG_AUTH); 
#endif
			}
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 197 "../../ipsec-tools/src/setkey/token.l"
{ yylval.num = SADB_X_AALG_NULL; BEGIN INITIAL; return(ALG_AUTH_NOKEY); }
	YY_BREAK
/* encryption alogorithm */
case 42:
YY_RULE_SETUP
#line 200 "../../ipsec-tools/src/setkey/token.l"
{ BEGIN S_ENCALG; return(F_ENC); }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 201 "../../ipsec-tools/src/setkey/token.l"
{ yylval.num = SADB_EALG_DESCBC; BEGIN INITIAL; return(ALG_ENC); }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 202 "../../ipsec-tools/src/setkey/token.l"
{ yylval.num = SADB_EALG_3DESCBC; BEGIN INITIAL; return(ALG_ENC); }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 203 "../../ipsec-tools/src/setkey/token.l"
{ yylval.num = SADB_EALG_NULL; BEGIN INITIAL; return(ALG_ENC_NOKEY); }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 204 "../../ipsec-tools/src/setkey/token.l"
{ yylval.num = SADB_EALG_NULL; BEGIN INITIAL; return(ALG_ENC_OLD); }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 205 "../../ipsec-tools/src/setkey/token.l"
{ yylval.num = SADB_X_EALG_BLOWFISHCBC; BEGIN INITIAL; return(ALG_ENC); }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 206 "../../ipsec-tools/src/setkey/token.l"
{ yylval.num = SADB_X_EALG_CAST128CBC; BEGIN INITIAL; return(ALG_ENC); }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 207 "../../ipsec-tools/src/setkey/token.l"
{ yylval.num = SADB_EALG_DESCBC; BEGIN INITIAL; return(ALG_ENC_DESDERIV); }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 208 "../../ipsec-tools/src/setkey/token.l"
{ yylval.num = SADB_EALG_DESCBC; BEGIN INITIAL; return(ALG_ENC_DES32IV); }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 209 "../../ipsec-tools/src/setkey/token.l"
{ yylval.num = SADB_X_EALG_TWOFISHCBC; BEGIN INITIAL; return(ALG_ENC); }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 210 "../../ipsec-tools/src/setkey/token.l"
{ 
#ifdef SADB_X_EALG_AESCBC
	yylval.num = SADB_X_EALG_AESCBC; BEGIN INITIAL; return(ALG_ENC); 
#endif
}
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 215 "../../ipsec-tools/src/setkey/token.l"
{ 
#ifdef SADB_X_EALG_AESCBC
	yylval.num = SADB_X_EALG_AESCBC; BEGIN INITIAL; return(ALG_ENC); 
#endif
}
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 220 "../../ipsec-tools/src/setkey/token.l"
{ yylval.num = SADB_X_EALG_AESCTR; BEGIN INITIAL; return(ALG_ENC); }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 221 "../../ipsec-tools/src/setkey/token.l"
{ 
#ifdef SADB_X_EALG_CAMELLIACBC
	yylval.num = SADB_X_EALG_CAMELLIACBC; BEGIN INITIAL; return(ALG_ENC); 
#endif
}
	YY_BREAK
/* compression algorithms */
case 56:
YY_RULE_SETUP
#line 228 "../../ipsec-tools/src/setkey/token.l"
{ return(F_COMP); }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 229 "../../ipsec-tools/src/setkey/token.l"
{ yylval.num = SADB_X_CALG_OUI; return(ALG_COMP); }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 230 "../../ipsec-tools/src/setkey/token.l"
{ yylval.num = SADB_X_CALG_DEFLATE; return(ALG_COMP); }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 231 "../../ipsec-tools/src/setkey/token.l"
{ yylval.num = SADB_X_CALG_LZS; return(ALG_COMP); }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 232 "../../ipsec-tools/src/setkey/token.l"
{ return(F_RAWCPI); }
	YY_BREAK
/* extension */
case 61:
YY_RULE_SETUP
#line 235 "../../ipsec-tools/src/setkey/token.l"
{ return(F_MODE); }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 236 "../../ipsec-tools/src/setkey/token.l"
{ yylval.num = IPSEC_MODE_TRANSPORT; return(MODE); }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 237 "../../ipsec-tools/src/setkey/token.l"
{ yylval.num = IPSEC_MODE_TUNNEL; return(MODE); }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 238 "../../ipsec-tools/src/setkey/token.l"
{ return(F_REQID); }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 239 "../../ipsec-tools/src/setkey/token.l"
{ return(F_EXT); }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 240 "../../ipsec-tools/src/setkey/token.l"
{ yylval.num = SADB_X_EXT_PRAND; return(EXTENSION); }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 241 "../../ipsec-tools/src/setkey/token.l"
{ yylval.num = SADB_X_EXT_PSEQ; return(EXTENSION); }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 242 "../../ipsec-tools/src/setkey/token.l"
{ yylval.num = SADB_X_EXT_PZERO; return(EXTENSION); }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 243 "../../ipsec-tools/src/setkey/token.l"
{ return(NOCYCLICSEQ); }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 244 "../../ipsec-tools/src/setkey/token.l"
{ return(F_REPLAY); }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 245 "../../ipsec-tools/src/setkey/token.l"
{ return(F_LIFETIME_HARD); }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 246 "../../ipsec-tools/src/setkey/token.l"
{ return(F_LIFETIME_SOFT); }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 247 "../../ipsec-tools/src/setkey/token.l"
{ return(F_LIFEBYTE_HARD); }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 248 "../../ipsec-tools/src/setkey/token.l"
{ return(F_LIFEBYTE_SOFT); }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 249 "../../ipsec-tools/src/setkey/token.l"
{ return(SECURITY_CTX); }
	YY_BREAK
/* ... */
case 76:
YY_RULE_SETUP
#line 252 "../../ipsec-tools/src/setkey/token.l"
{ return(ANY); }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 253 "../../ipsec-tools/src/setkey/token.l"
{ }
	YY_BREAK
case 78:
/* rule 78 can match eol */
YY_RULE_SETUP
#line 254 "../../ipsec-tools/src/setkey/token.l"
{ lineno++; }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 255 "../../ipsec-tools/src/setkey/token.l"

	YY_BREAK
case 80:
YY_RULE_SETUP
#line 256 "../../ipsec-tools/src/setkey/token.l"
{ return(EOT); }
	YY_BREAK
/* for address parameters: /prefix, [port] */
case 81:
YY_RULE_SETUP
#line 259 "../../ipsec-tools/src/setkey/token.l"
{ return SLASH; }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 260 "../../ipsec-tools/src/setkey/token.l"
{ return BLCL; }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 261 "../../ipsec-tools/src/setkey/token.l"
{ return ELCL; }
	YY_BREAK
/* parameter */
case 84:
YY_RULE_SETUP
#line 264 "../../ipsec-tools/src/setkey/token.l"
{
			char *bp;

			yylval.ulnum = strtoul(setkeyyytext, &bp, 10);
			return(DECSTRING);
		}
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 271 "../../ipsec-tools/src/setkey/token.l"
{
			yylval.val.buf = strdup(setkeyyytext + 2);
			if (!yylval.val.buf)
				yyfatal("insufficient memory");
			yylval.val.len = strlen(yylval.val.buf);

			return(HEXSTRING);
		}
	YY_BREAK
case 86:
/* rule 86 can match eol */
YY_RULE_SETUP
#line 280 "../../ipsec-tools/src/setkey/token.l"
{
			char *p = setkeyyytext;
			while (*++p != '"') ;
			*p = '\0';
			setkeyyytext++;
			yylval.val.len = setkeyyyleng - 2;
			yylval.val.buf = strdup(setkeyyytext);
			if (!yylval.val.buf)
				yyfatal("insufficient memory");

			return(QUOTEDSTRING);
		}
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 293 "../../ipsec-tools/src/setkey/token.l"
{
			yylval.val.len = setkeyyyleng;
			yylval.val.buf = strdup(setkeyyytext);
			if (!yylval.val.buf)
				yyfatal("insufficient memory");
			return(STRING);
		}
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 301 "../../ipsec-tools/src/setkey/token.l"
{
			yylval.val.len = setkeyyyleng;
			yylval.val.buf = strdup(setkeyyytext);
			if (!yylval.val.buf)
				yyfatal("insufficient memory");
			return(STRING);
		}
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 309 "../../ipsec-tools/src/setkey/token.l"
{
			yyfatal("Syntax error");
			/*NOTREACHED*/
		}
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 314 "../../ipsec-tools/src/setkey/token.l"
ECHO;
	YY_BREAK
#line 1934 "<stdout>"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(S_PL):
case YY_STATE_EOF(S_AUTHALG):
case YY_STATE_EOF(S_ENCALG):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed setkeyyyin at a new source and called
			 * setkeyyylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = setkeyyyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( setkeyyywrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * setkeyyytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of setkeyyylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			yy_size_t num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				yy_size_t new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					setkeyyyrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			setkeyyyrestart(setkeyyyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) setkeyyyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 564 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	int yy_is_jam;
    	char *yy_cp = (yy_c_buf_p);

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 564 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 563);

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			yy_size_t offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					setkeyyyrestart(setkeyyyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( setkeyyywrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve setkeyyytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void setkeyyyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        setkeyyyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            setkeyyy_create_buffer(setkeyyyin,YY_BUF_SIZE );
	}

	setkeyyy_init_buffer(YY_CURRENT_BUFFER,input_file );
	setkeyyy_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void setkeyyy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		setkeyyypop_buffer_state();
	 *		setkeyyypush_buffer_state(new_buffer);
     */
	setkeyyyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	setkeyyy_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (setkeyyywrap()) processing, but the only time this flag
	 * is looked at is after setkeyyywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void setkeyyy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	setkeyyyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE setkeyyy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) setkeyyyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in setkeyyy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) setkeyyyalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in setkeyyy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	setkeyyy_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with setkeyyy_create_buffer()
 * 
 */
    void setkeyyy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		setkeyyyfree((void *) b->yy_ch_buf  );

	setkeyyyfree((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a setkeyyyrestart() or at EOF.
 */
    static void setkeyyy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	setkeyyy_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then setkeyyy_init_buffer was _probably_
     * called from setkeyyyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void setkeyyy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		setkeyyy_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void setkeyyypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	setkeyyyensure_buffer_stack();

	/* This block is copied from setkeyyy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from setkeyyy_switch_to_buffer. */
	setkeyyy_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void setkeyyypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	setkeyyy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		setkeyyy_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void setkeyyyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)setkeyyyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in setkeyyyensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)setkeyyyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in setkeyyyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE setkeyyy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) setkeyyyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in setkeyyy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	setkeyyy_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to setkeyyylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       setkeyyy_scan_bytes() instead.
 */
YY_BUFFER_STATE setkeyyy_scan_string (yyconst char * yystr )
{
    
	return setkeyyy_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to setkeyyylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE setkeyyy_scan_bytes  (yyconst char * yybytes, yy_size_t  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	yy_size_t i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) setkeyyyalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in setkeyyy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = setkeyyy_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in setkeyyy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up setkeyyytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		setkeyyytext[setkeyyyleng] = (yy_hold_char); \
		(yy_c_buf_p) = setkeyyytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		setkeyyyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int setkeyyyget_lineno  (void)
{
        
    return setkeyyylineno;
}

/** Get the input stream.
 * 
 */
FILE *setkeyyyget_in  (void)
{
        return setkeyyyin;
}

/** Get the output stream.
 * 
 */
FILE *setkeyyyget_out  (void)
{
        return setkeyyyout;
}

/** Get the length of the current token.
 * 
 */
yy_size_t setkeyyyget_leng  (void)
{
        return setkeyyyleng;
}

/** Get the current token.
 * 
 */

char *setkeyyyget_text  (void)
{
        return setkeyyytext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void setkeyyyset_lineno (int  line_number )
{
    
    setkeyyylineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see setkeyyy_switch_to_buffer
 */
void setkeyyyset_in (FILE *  in_str )
{
        setkeyyyin = in_str ;
}

void setkeyyyset_out (FILE *  out_str )
{
        setkeyyyout = out_str ;
}

int setkeyyyget_debug  (void)
{
        return setkeyyy_flex_debug;
}

void setkeyyyset_debug (int  bdebug )
{
        setkeyyy_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from setkeyyylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    setkeyyyin = stdin;
    setkeyyyout = stdout;
#else
    setkeyyyin = (FILE *) 0;
    setkeyyyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * setkeyyylex_init()
     */
    return 0;
}

/* setkeyyylex_destroy is for both reentrant and non-reentrant scanners. */
int setkeyyylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		setkeyyy_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		setkeyyypop_buffer_state();
	}

	/* Destroy the stack itself. */
	setkeyyyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * setkeyyylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *setkeyyyalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *setkeyyyrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void setkeyyyfree (void * ptr )
{
	free( (char *) ptr );	/* see setkeyyyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 314 "../../ipsec-tools/src/setkey/token.l"



void
yyfatal(s)
	const char *s;
{
	yyerror(s);
	exit(1);
}

void
yyerror(s)
	const char *s;
{
	printf("line %d: %s at [%s]\n", lineno, s, setkeyyytext);
}

int
parse(fp)
	FILE **fp;
{
	setkeyyyin = *fp;

	lineno = 1;
	parse_init();

	if (yyparse()) {
		printf("parse failed, line %d.\n", lineno);
		return(-1);
	}

	return(0);
}

int
parse_string (char *src)
{
	int             result;
	YY_BUFFER_STATE buf_state;

	buf_state = setkeyyy_scan_string(src);
	result = yyparse();
	setkeyyy_delete_buffer(buf_state);
	return result;
}


